<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "Missouri";
    var qsoPartyUrl = "http://www.w0ma.org/mo_qso_party/index.html";
    var overlayUrl = "http://www.no5w.com/OverlayMissouriRev3.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Adair", "adr");
  countySelection.options[1] = new Option("Andrew", "and");
  countySelection.options[2] = new Option("Atchison", "atc");
  countySelection.options[3] = new Option("Audrain", "aud");
  countySelection.options[4] = new Option("Barry", "bar");
  countySelection.options[5] = new Option("Barton", "btn");
  countySelection.options[6] = new Option("Bates", "bat");
  countySelection.options[7] = new Option("Benton", "ben");
  countySelection.options[8] = new Option("Bollinger", "bol");
  countySelection.options[9] = new Option("Boone", "boo");
  countySelection.options[10] = new Option("Buchanan", "buc");
  countySelection.options[11] = new Option("Butler", "btr");
  countySelection.options[12] = new Option("Caldwell", "cwl");
  countySelection.options[13] = new Option("Callaway", "cal");
  countySelection.options[14] = new Option("Camden", "cam");
  countySelection.options[15] = new Option("CapeGirardeau", "cpg");
  countySelection.options[16] = new Option("Carroll", "crl");
  countySelection.options[17] = new Option("Carter", "car");
  countySelection.options[18] = new Option("Cass", "cas");
  countySelection.options[19] = new Option("Cedar", "ced");
  countySelection.options[20] = new Option("Chariton", "chn");
  countySelection.options[21] = new Option("Christian", "chr");
  countySelection.options[22] = new Option("Clark", "clk");
  countySelection.options[23] = new Option("Clay", "cla");
  countySelection.options[24] = new Option("Clinton", "cln");
  countySelection.options[25] = new Option("Cole", "col");
  countySelection.options[26] = new Option("Cooper", "cop");
  countySelection.options[27] = new Option("Crawford", "cra");
  countySelection.options[28] = new Option("Dade", "dad");
  countySelection.options[29] = new Option("Dallas", "dal");
  countySelection.options[30] = new Option("Daviess", "dvs");
  countySelection.options[31] = new Option("DeKalb", "dek");
  countySelection.options[32] = new Option("Dent", "den");
  countySelection.options[33] = new Option("Douglas", "dgl");
  countySelection.options[34] = new Option("Dunklin", "dun");
  countySelection.options[35] = new Option("Franklin", "fra");
  countySelection.options[36] = new Option("Gasconade", "gas");
  countySelection.options[37] = new Option("Gentry", "gen");
  countySelection.options[38] = new Option("Greene", "grn");
  countySelection.options[39] = new Option("Grundy", "gru");
  countySelection.options[40] = new Option("Harrison", "har");
  countySelection.options[41] = new Option("Henry", "hen");
  countySelection.options[42] = new Option("Hickory", "hic");
  countySelection.options[43] = new Option("Holt", "hlt");
  countySelection.options[44] = new Option("Howard", "how");
  countySelection.options[45] = new Option("Howell", "hwl");
  countySelection.options[46] = new Option("Iron", "irn");
  countySelection.options[47] = new Option("Jackson", "jac");
  countySelection.options[48] = new Option("Jasper", "jas");
  countySelection.options[49] = new Option("Jefferson", "jef");
  countySelection.options[50] = new Option("Johnson", "jon");
  countySelection.options[51] = new Option("Knox", "knx");
  countySelection.options[52] = new Option("Laclede", "lac");
  countySelection.options[53] = new Option("Lafayette", "laf");
  countySelection.options[54] = new Option("Lawrence", "law");
  countySelection.options[55] = new Option("Lewis", "lew");
  countySelection.options[56] = new Option("Lincoln", "lcn");
  countySelection.options[57] = new Option("Linn", "lin");
  countySelection.options[58] = new Option("Livingston", "liv");
  countySelection.options[59] = new Option("Macon", "mac");
  countySelection.options[60] = new Option("Madison", "mad");
  countySelection.options[61] = new Option("Maries", "mre");
  countySelection.options[62] = new Option("Marion", "mar");
  countySelection.options[63] = new Option("McDonald", "mcd");
  countySelection.options[64] = new Option("Mercer", "mer");
  countySelection.options[65] = new Option("Miller", "mil");
  countySelection.options[66] = new Option("Mississippi", "mis");
  countySelection.options[67] = new Option("Moniteau", "mnt");
  countySelection.options[68] = new Option("Monroe", "mon");
  countySelection.options[69] = new Option("Montgomery", "mgm");
  countySelection.options[70] = new Option("Morgan", "mor");
  countySelection.options[71] = new Option("NewMadrid", "nmd");
  countySelection.options[72] = new Option("Newton", "nwt");
  countySelection.options[73] = new Option("Nodaway", "nod");
  countySelection.options[74] = new Option("Oregon", "ore");
  countySelection.options[75] = new Option("Osage", "osa");
  countySelection.options[76] = new Option("Ozark", "oza");
  countySelection.options[77] = new Option("Pemiscot", "pem");
  countySelection.options[78] = new Option("Perry", "per");
  countySelection.options[79] = new Option("Pettis", "pet");
  countySelection.options[80] = new Option("Phelps", "phe");
  countySelection.options[81] = new Option("Pike", "pik");
  countySelection.options[82] = new Option("Platte", "pla");
  countySelection.options[83] = new Option("Polk", "pol");
  countySelection.options[84] = new Option("Pulaski", "pul");
  countySelection.options[85] = new Option("Putnam", "put");
  countySelection.options[86] = new Option("Ralls", "ral");
  countySelection.options[87] = new Option("Randolph", "ran");
  countySelection.options[88] = new Option("Ray", "ray");
  countySelection.options[89] = new Option("Reynolds", "rey");
  countySelection.options[90] = new Option("Ripley", "rip");
  countySelection.options[91] = new Option("SainteGenevieve", "stg");
  countySelection.options[92] = new Option("Saline", "sal");
  countySelection.options[93] = new Option("Schuyler", "sch");
  countySelection.options[94] = new Option("Scotland", "sct");
  countySelection.options[95] = new Option("Scott", "sco");
  countySelection.options[96] = new Option("Shannon", "sha");
  countySelection.options[97] = new Option("Shelby", "shl");
  countySelection.options[98] = new Option("St.Charles", "stc");
  countySelection.options[99] = new Option("St.Clair", "scl");
  countySelection.options[100] = new Option("St.Francois", "stf");
  countySelection.options[101] = new Option("St.Louis", "stl");
  countySelection.options[102] = new Option("St.LouisCounty", "slc");
  countySelection.options[103] = new Option("Stoddard", "std");
  countySelection.options[104] = new Option("Stone", "stn");
  countySelection.options[105] = new Option("Sullivan", "sul");
  countySelection.options[106] = new Option("Taney", "tan");
  countySelection.options[107] = new Option("Texas", "tex");
  countySelection.options[108] = new Option("Vernon", "vrn");
  countySelection.options[109] = new Option("Warren", "war");
  countySelection.options[110] = new Option("Washington", "was");
  countySelection.options[111] = new Option("Wayne", "way");
  countySelection.options[112] = new Option("Webster", "web");
  countySelection.options[113] = new Option("Worth", "wor");
  countySelection.options[114] = new Option("Wright", "wrt");
  addMarker(40.19190000, -92.60080000, "Adair", "adr");
  addMarker(39.97500000, -94.83160000, "Andrew", "and");
  addMarker(40.42350000, -95.47600000, "Atchison", "atc");
  addMarker(39.20340000, -91.86170000, "Audrain", "aud");
  addMarker(36.71520000, -93.82550000, "Barry", "bar");
  addMarker(37.50150000, -94.34570000, "Barton", "btn");
  addMarker(38.25190000, -94.33200000, "Bates", "bat");
  addMarker(38.29900000, -93.29130000, "Benton", "ben");
  addMarker(37.31970000, -90.04220000, "Bollinger", "bol");
  addMarker(38.94600000, -92.33740000, "Boone", "boo");
  addMarker(39.67630000, -94.85740000, "Buchanan", "buc");
  addMarker(36.71240000, -90.40700000, "Butler", "btr");
  addMarker(39.65660000, -93.98340000, "Caldwell", "cwl");
  addMarker(38.81130000, -91.92990000, "Callaway", "cal");
  addMarker(38.03550000, -92.74420000, "Camden", "cam");
  addMarker(37.36620000, -89.64390000, "CapeGirardeau", "cpg");
  addMarker(39.41100000, -93.43190000, "Carroll", "crl");
  addMarker(36.95590000, -90.94300000, "Carter", "car");
  addMarker(38.64620000, -94.33860000, "Cass", "cas");
  addMarker(37.73690000, -93.84250000, "Cedar", "ced");
  addMarker(39.46430000, -92.98760000, "Chariton", "chn");
  addMarker(36.95380000, -93.25650000, "Christian", "chr");
  addMarker(40.43120000, -91.68510000, "Clark", "clk");
  addMarker(39.28290000, -94.40900000, "Clay", "cla");
  addMarker(39.60130000, -94.40410000, "Clinton", "cln");
  addMarker(38.53100000, -92.24930000, "Cole", "col");
  addMarker(38.87230000, -92.77920000, "Cooper", "cop");
  addMarker(37.95440000, -91.31480000, "Crawford", "cra");
  addMarker(37.43180000, -93.84990000, "Dade", "dad");
  addMarker(37.65960000, -93.01890000, "Dallas", "dal");
  addMarker(39.96050000, -93.98890000, "Daviess", "dvs");
  addMarker(39.89260000, -94.40440000, "DeKalb", "dek");
  addMarker(37.60330000, -91.48120000, "Dent", "den");
  addMarker(36.93230000, -92.49900000, "Douglas", "dgl");
  addMarker(36.31330000, -90.16580000, "Dunklin", "dun");
  addMarker(38.45620000, -91.05070000, "Franklin", "fra");
  addMarker(38.43290000, -91.50520000, "Gasconade", "gas");
  addMarker(40.21090000, -94.41040000, "Gentry", "gen");
  addMarker(37.25810000, -93.34370000, "Greene", "grn");
  addMarker(40.11290000, -93.56330000, "Grundy", "gru");
  addMarker(40.35520000, -93.99780000, "Harrison", "har");
  addMarker(38.38420000, -93.79320000, "Henry", "hen");
  addMarker(37.93790000, -93.31970000, "Hickory", "hic");
  addMarker(40.06320000, -95.27150000, "Holt", "hlt");
  addMarker(39.15560000, -92.68800000, "Howard", "how");
  addMarker(36.77730000, -91.88800000, "Howell", "hwl");
  addMarker(37.50550000, -90.84500000, "Iron", "irn");
  addMarker(39.03490000, -94.35660000, "Jackson", "jac");
  addMarker(37.20620000, -94.33540000, "Jasper", "jas");
  addMarker(38.25270000, -90.51490000, "Jefferson", "jef");
  addMarker(38.74700000, -93.81120000, "Johnson", "jon");
  addMarker(40.12680000, -92.14800000, "Knox", "knx");
  addMarker(37.68430000, -92.55440000, "Laclede", "lac");
  addMarker(39.10080000, -93.79580000, "Lafayette", "laf");
  addMarker(37.10640000, -93.83400000, "Lawrence", "law");
  addMarker(40.10120000, -91.69410000, "Lewis", "lew");
  addMarker(39.04900000, -90.96490000, "Lincoln", "lcn");
  addMarker(39.86860000, -93.10610000, "Linn", "lin");
  addMarker(39.78940000, -93.51110000, "Livingston", "liv");
  addMarker(39.82190000, -92.57290000, "Macon", "mac");
  addMarker(37.47790000, -90.34410000, "Madison", "mad");
  addMarker(38.15160000, -91.91420000, "Maries", "mre");
  addMarker(39.80290000, -91.57670000, "Marion", "mar");
  addMarker(36.63260000, -94.34270000, "McDonald", "mcd");
  addMarker(40.42210000, -93.57070000, "Mercer", "mer");
  addMarker(38.22360000, -92.43860000, "Miller", "mil");
  addMarker(36.81850000, -89.30940000, "Mississippi", "mis");
  addMarker(38.67500000, -92.61090000, "Moniteau", "mnt");
  addMarker(39.50040000, -92.01120000, "Monroe", "mon");
  addMarker(38.91200000, -91.45370000, "Montgomery", "mgm");
  addMarker(38.43950000, -92.85150000, "Morgan", "mor");
  addMarker(36.60380000, -89.65000000, "NewMadrid", "nmd");
  addMarker(36.90230000, -94.33900000, "Newton", "nwt");
  addMarker(40.35230000, -94.90050000, "Nodaway", "nod");
  addMarker(36.69290000, -91.39710000, "Oregon", "ore");
  addMarker(38.49800000, -91.91800000, "Osage", "osa");
  addMarker(36.65160000, -92.44230000, "Ozark", "oza");
  addMarker(36.21330000, -89.74810000, "Pemiscot", "pem");
  addMarker(37.73480000, -89.81160000, "Perry", "per");
  addMarker(38.72460000, -93.28170000, "Pettis", "pet");
  addMarker(37.87620000, -91.77720000, "Phelps", "phe");
  addMarker(39.36860000, -91.09080000, "Pike", "pik");
  addMarker(39.34320000, -94.85160000, "Platte", "pla");
  addMarker(37.62340000, -93.40280000, "Polk", "pol");
  addMarker(37.81190000, -92.21740000, "Pulaski", "pul");
  addMarker(40.46600000, -93.02030000, "Putnam", "put");
  addMarker(39.50260000, -91.44820000, "Ralls", "ral");
  addMarker(39.42850000, -92.50420000, "Randolph", "ran");
  addMarker(39.33070000, -93.98550000, "Ray", "ray");
  addMarker(37.32710000, -91.02430000, "Reynolds", "rey");
  addMarker(36.66100000, -90.85070000, "Ripley", "rip");
  addMarker(37.89870000, -90.19200000, "SainteGenevieve", "stg");
  addMarker(39.17000000, -93.17290000, "Saline", "sal");
  addMarker(40.47040000, -92.53560000, "Schuyler", "sch");
  addMarker(40.45330000, -92.14730000, "Scotland", "sct");
  addMarker(37.05640000, -89.54980000, "Scott", "sco");
  addMarker(37.15330000, -91.33750000, "Shannon", "sha");
  addMarker(39.77930000, -92.06970000, "Shelby", "shl");
  addMarker(38.75090000, -90.53680000, "St.Charles", "stc");
  addMarker(38.02410000, -93.78150000, "St.Clair", "scl");
  addMarker(37.85880000, -90.37920000, "St.Francois", "stf");
  addMarker(38.65320000, -90.24300000, "St.Louis", "stl");
  addMarker(38.63830000, -90.42700000, "St.LouisCounty", "slc");
  addMarker(36.87730000, -89.97390000, "Stoddard", "std");
  addMarker(36.74710000, -93.45860000, "Stone", "stn");
  addMarker(40.20980000, -93.11130000, "Sullivan", "sul");
  addMarker(36.65730000, -93.04010000, "Taney", "tan");
  addMarker(37.32700000, -91.95000000, "Texas", "tex");
  addMarker(37.84990000, -94.33810000, "Vernon", "vrn");
  addMarker(38.77020000, -91.18860000, "Warren", "war");
  addMarker(37.97040000, -90.87000000, "Washington", "was");
  addMarker(37.11960000, -90.44500000, "Wayne", "way");
  addMarker(37.27720000, -92.87790000, "Webster", "web");
  addMarker(40.47810000, -94.42330000, "Worth", "wor");
  addMarker(37.27060000, -92.46960000, "Wright", "wrt");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

